==> image-citation-generator-0.1.0.tgz: package/README.md <==
<div align="center">
<h1 style="color: green">Image Citation Generator</h1>
</div>

<br/>

# <span style="color: #258589">What is this project</span>

### This project allows you to generate an image to highlight a quote from an author.

### Here is an example :
![Quote from akhenaton](ressources/new-img.png)

<br/>

# <span style="color: #258589">How to use</span>

## Step-1

### Installation via npm

```bash
npm i image-citation-generator
```

## Step-2

### Call the package

```javascript
const Citation = require('image-citation-generator');
```

## Step-3

### Initialize the class

```javascript
const citation = new Citation("./path-to-background.jpg", "./output.png", "Author", "Citation", "[black or white]");
```

## Step-4

### Generate citation

```javascript
citation.generate();
```

<br/>

# <span style="color: #258589">Governance</span>

### This project is under Founder-leader governance

## **"Image Citation Generator"**  `Belongs To`

* Tom Ait-ouarab ( `Benevolent Dictators for Life | dev` )

## **Contributor of the project**

* Julien Coudert ( `dev` | `documentation` )
* Omar Aboulbarge ( `documentatione` )
* Dorian Jullian ( `dev` )

See the [contributor](https://github.com/us3rT0m/image-citation-generator/graphs/contributors)

<br/>

# <span style="color: #258589">License</span>

**<span style="color: green">Image Citation Generator</span> is licensed under the [MIT](./LICENSE) license.**

<br/>

# <span style="color: #258589">Contributing</span>

If you would like to join the adventure and contribute to the growth of our package, please note that we are open to contributions from all. 
Please read our chapter on [contribution](./CONTRIBUTING.md) before you start.

<br/>

# <span style="color: #258589">Code of conduct</span>

Before you start drop some shit in our project, please read our [code of conduct](./CODE_OF_CONDUCT.md)

==> image-citation-generator-0.1.1.tgz: package/README.md <==
<div align="center">
<h1 style="color: green">Image Citation Generator</h1>
</div>

<br/>

# <span style="color: #258589">What is this project</span>

### This project allows you to generate an image to highlight a quote from an author.

### Here is an example :
![Quote from akhenaton](https://github.com/us3rT0m/image-citation-generator/blob/main/ressources/new-img.png)

<br/>

# <span style="color: #258589">How to use</span>

## Step-1

### Installation via npm

```bash
npm i image-citation-generator
```

## Step-2

### Call the package

```javascript
const Citation = require('image-citation-generator');
```

## Step-3

### Initialize the class

```javascript
const citation = new Citation("./path-to-background.jpg", "./output.png", "Author", "Citation", "[black or white]");
```

## Step-4

### Generate citation

```javascript
citation.generate();
```

<br/>

# <span style="color: #258589">Governance</span>

### This project is under Founder-leader governance

## **"Image Citation Generator"**  `Belongs To`

* Tom Ait-ouarab ( `Benevolent Dictators for Life | dev` )

## **Contributor of the project**

* Julien Coudert ( `dev` | `documentation` )
* Omar Aboulbarge ( `documentatione` )
* Dorian Jullian ( `dev` )

See the [contributor](https://github.com/us3rT0m/image-citation-generator/graphs/contributors)

<br/>

# <span style="color: #258589">License</span>

**<span style="color: green">Image Citation Generator</span> is licensed under the [MIT](https://github.com/us3rT0m/image-citation-generator/blob/main/LICENSE) license.**

<br/>

# <span style="color: #258589">Contributing</span>

If you would like to join the adventure and contribute to the growth of our package, please note that we are open to contributions from all. 
Please read our chapter on [contribution](https://github.com/us3rT0m/image-citation-generator/blob/main/CONTRIBUTING.md) before you start.

<br/>

# <span style="color: #258589">Code of conduct</span>

Before you start drop some shit in our project, please read our [code of conduct](https://github.com/us3rT0m/image-citation-generator/blob/main/CODE_OF_CONDUCT.md)
